==> dde-control-center_5.5.89.orig.tar.xz: dde-control-center-5.5.89/translations/recovery_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="65"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Откат системы, пожалуйста подождите...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="266"/>
        <source>Rollback failed.</source>
        <translation>Не удалось откатить систему</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Reboot</source>
        <translation>Перезагрузка</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="280"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Вы уверены, что хотите откатиться к версии %1, сохраненной на %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="283"/>
        <source>Cancel and Reboot</source>
        <translation>Отменить и Перезагрузить</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="284"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
</TS>

==> dde-control-center_5.5.197.orig.tar.xz: dde-control-center-5.5.197/translations/recovery_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="33"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Откат системы, пожалуйста подождите...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="250"/>
        <source>Rollback failed.</source>
        <translation>Откат завершился неудался</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="255"/>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Вы уверены, что хотите откатиться к версии %1, сохраненной на %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="267"/>
        <source>Cancel and Reboot</source>
        <translation>Отменить и Перезагрузить</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="268"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
</TS>
